"use client";

import RippleButton from "@/components/ui/ripple-button";
import { ImageBaseUrl } from "@/configs/api";
import { addCart, removeCart } from "@/servers/actions/cart-action";
import { motion } from "framer-motion";
import Cookies from "js-cookie";
import { Minus, Plus, Trash } from "lucide-react";
import { useLocale, useTranslations } from "next-intl";
import Image from "next/image";
import { useRouter } from "next/navigation";
import { useTransition } from "react";
import { toast } from "sonner";


const ProductRecord = ({
	lastItem = false,
	quantity,
	onIncrement,
	onDecrement,
	onRemove,
	product,
	disabled = false,
}: any) => {
	const locale = useLocale();

	const imagePath = product?.thumbnail?.image_path;
	const imageSrc = imagePath ? ImageBaseUrl + product?.thumbnail?.image_path : "/default-image.png";
	const imageAlt = product?.thumbnail?.name || "Product image";

	return (
		<motion.div
			initial={{ opacity: 0, y: 20 }}
			animate={{ opacity: 1, y: 0 }}
			transition={{ duration: 0.5 }}
			style={lastItem ? { border: "none" } : {}}
			className="flex flex-row items-center justify-between border-b-[1px] border-[#E4E4E4] py-4"
		>
			<div className="flex items-center justify-start gap-3 md:gap-7">
				<Image
					src={imageSrc}
					alt={imageAlt}
					width={160}
					height={160}
					className="h-[100px] w-[100px] md:h-[160px] md:w-[160px] rounded-lg"
				/>
				<div>
					<p className="mb-1 text-[#8E8F94]">{locale === "ar" ? product?.category?.name_ar : product?.category?.name_en}</p>
					<p className="mb-3 text-lg text-custom-primary-accent md:text-xl">
						{locale === "ar" ? product?.name_ar : product?.name_en}
					</p>
					<div className="flex items-center gap-2">
						<p className="text-lg font-semibold leading-7 text-custom-primary-accent">
							{product?.base_price}
						</p>
						<Image
							src={"/coins/Saudi_Riyal.jpg"}
							alt="Saudi_Riyal"
							width={12}
							height={12}
						/>
					</div>

				</div>
			</div>
			<div className="flex flex-col items-center gap-3 md:flex-row md:gap-7">
				<RippleButton
					rippleColor="#2895C8"
					className="flex h-8 w-8 items-center justify-center rounded-none md:h-10 md:w-10"
					style={{ border: "1px solid #2895C8" }}
					onClick={onIncrement}
					disabled={disabled}
				>
					<Plus absoluteStrokeWidth className="text-custom-primary-accent" />
				</RippleButton>
				<p className="text-custom-primary-accent">{quantity}</p>
				<RippleButton
					rippleColor="#8E8F94"
					className="flex h-8 w-8 items-center justify-center rounded-none md:h-10 md:w-10"
					style={{ border: "1px solid #8E8F94" }}
					onClick={onDecrement}
					disabled={quantity === 0 || disabled}
				>
					<Minus absoluteStrokeWidth className="text-[#8E8F94]" />
				</RippleButton>
				<RippleButton
					rippleColor="#8E8F94"
					className="flex h-8 w-8 items-center justify-center rounded-none md:h-10 md:w-10"
					onClick={onRemove}
					disabled={disabled}
				>
					<Trash absoluteStrokeWidth className="text-red-500" />
				</RippleButton>
			</div>
		</motion.div>
	);
};

function ProductsInBasket({ products, refetch }: any) {
	const t = useTranslations("Cart");
	const router = useRouter();
	const [isPending, startTransition] = useTransition();


	const handleUpdateCart = async (id: number, quantity: number) => {
		const _session = Cookies.get("__t");

		if (!_session) {
			toast.error(t("Please login to rate this product"));
			return;
		}

		console.log("quantity: ", quantity);
		console.log("id: ", id);
		startTransition(async () => {
			try {
				const result = await addCart({
					product_id: id,
					quantity: quantity,
				});
				if (result?.success) {
					toast.success(t("Quantity updated successfully!"), {
						style: { backgroundColor: "green", color: "white" },
					});
					refetch();
				} else {
					toast.error(t(result?.message?.replace(".", "")));
					if (result?.status === 401) router.push("/login");
				}
			} catch (error: any) {
				console.log("error: ", error);
				toast.error("Something went wrong");
			}
		});
	};


	const handleRemove = (id: number, quantity: number) => {
		console.log("id: ", id);
		console.log("quantity: ", quantity);
		startTransition(async () => {
			try {
				const result = await removeCart(id);
				if (result?.success) {
					toast.success(t("The product has been removed from the cart"), {
						style: { backgroundColor: "green", color: "white" },
					});
					refetch();
				} else {
					toast.error(t(result?.message?.replace(".", "")));
					if (result?.status === 401) router.push("/login");
				}

			} catch (error: any) {
				console.log("error: ", error);
				toast.error("Something went wrong");
			}
		});
	};

	return (
		<div className="mt-5 w-full">
			{
				products?.map((product: any, index: any) => (
					<ProductRecord
						key={product.id}
						lastItem={index === products.length - 1}
						quantity={product?.quantity}
						onIncrement={() => handleUpdateCart(product.product_id, product.quantity + 1)}
						onDecrement={() => handleUpdateCart(product.product_id, product.quantity - 1)}
						onRemove={() => handleRemove(product.product_id, product.quantity)}
						product={product?.product}
						disabled={isPending}
					/>
				))
			}
		</div>
	);
}

export default ProductsInBasket;
